"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const open_1 = tslib_1.__importDefault(require("open"));
const commands_1 = require("@graphql-inspector/commands");
const logger_1 = require("@graphql-inspector/logger");
const node_1 = require("@graphql-yoga/node");
const fake_js_1 = require("./fake.js");
exports.default = (0, commands_1.createCommand)(api => {
    const { loaders } = api;
    return {
        command: 'serve <schema>',
        describe: 'Runs server with fake data based on schema',
        builder(yargs) {
            return yargs
                .positional('schema', {
                describe: 'Point to a schema',
                type: 'string',
                demandOption: true,
            })
                .options({
                port: {
                    alias: 'p',
                    describe: 'Port',
                    type: 'number',
                    default: 4000,
                },
            });
        },
        handler(args) {
            var _a;
            return tslib_1.__awaiter(this, void 0, void 0, function* () {
                const { headers, token } = (0, commands_1.parseGlobalArgs)(args);
                const apolloFederation = args.federation || false;
                const aws = args.aws || false;
                const method = ((_a = args.method) === null || _a === void 0 ? void 0 : _a.toUpperCase()) || 'POST';
                const schema = yield loaders.loadSchema(args.schema, {
                    headers,
                    token,
                    method,
                }, apolloFederation, aws);
                const port = args.port;
                try {
                    (0, fake_js_1.fake)(schema);
                    const server = (0, node_1.createServer)({
                        schema,
                        port,
                        cors: true,
                        logging: false,
                    });
                    yield server.start();
                    const url = `http://localhost:${port}`;
                    logger_1.Logger.success(`GraphQL API:    ${url}`);
                    yield (0, open_1.default)(url);
                    const shutdown = () => {
                        server.stop();
                        process.exit(0);
                    };
                    process.on('SIGINT', shutdown);
                    process.on('SIGTERM', shutdown);
                }
                catch (e) {
                    logger_1.Logger.error(e.message || e);
                }
            });
        },
    };
});
